# bounty
Unofficial Robinhood client

[![Build Status](https://travis-ci.org/jlane9/bounty.svg?branch=master)](https://travis-ci.org/jlane9/bounty)
[![PyPI version](https://badge.fury.io/py/bounty.svg)](https://badge.fury.io/py/bounty)
[![Python version](https://img.shields.io/pypi/pyversions/bounty.svg)](https://pypi.python.org/pypi/bounty)
[![License](https://img.shields.io/pypi/l/bounty.svg)](https://pypi.python.org/pypi/bounty)
[![Status](https://img.shields.io/pypi/status/bounty.svg)](https://pypi.python.org/pypi/bounty)
[![Coverage Status](https://coveralls.io/repos/github/jlane9/bounty/badge.svg?branch=master)](https://coveralls.io/github/jlane9/bounty?branch=master)
[![Maintainability](https://api.codeclimate.com/v1/badges/02ed038248176e7b7983/maintainability)](https://codeclimate.com/github/jlane9/bounty/maintainability)
[![Requirements Status](https://requires.io/github/jlane9/bounty/requirements.svg?branch=master)](https://requires.io/github/jlane9/bounty/requirements/?branch=master)
[![Documentation Status](https://readthedocs.org/projects/bounty/badge/?version=latest)](http://bounty.readthedocs.io/en/latest/?badge=latest)
